@@ -56,6 +56,7 @@ static struct TdsFdwOption valid_options[] =
 	{ "port",					ForeignServerRelationId },
 	{ "database",				ForeignServerRelationId },
 	{ "dbuse",					ForeignServerRelationId },
+    { "sqlserver_ansi_mode",    ForeignServerRelationId },
 	{ "tds_version",			ForeignServerRelationId },
 	{ "msg_handler",			ForeignServerRelationId },
 	{ "row_estimate_method",	ForeignServerRelationId },
@@ -127,6 +128,7 @@ void tdsValidateOptions(List *options_list, Oid context, TdsFdwOptionSet* option
 	else if (context == ForeignTableRelationId)
 	{
 		tdsGetForeignTableOptions(options_list, option_set);
+		tdsSetDefaultOptions(option_set);
 		tdsValidateForeignTableOptionSet(option_set);
 	}
 	
@@ -316,6 +318,17 @@ void tdsGetForeignServerOptions(List *options_list, TdsFdwOptionSet *option_set)
 			option_set->dbuse = atoi(defGetString(def));	
 		}	
 
+		else if(strcmp(def->defname, "sqlserver_ansi_mode") == 0)
+		{
+			if (option_set->sqlserver_ansi_mode)
+				ereport(ERROR,
+					(errcode(ERRCODE_SYNTAX_ERROR),
+						errmsg("Redundant option: sqlserver_ansi_mode (%s)", defGetBoolean(def))
+					));
+
+			option_set->sqlserver_ansi_mode = defGetBoolean(def);
+		}
+
 		else if (strcmp(def->defname, "tds_version") == 0)
 		{
 			int tds_version_test = 0;
@@ -502,7 +515,7 @@ void tdsGetForeignServerTableOptions(List *options_list, TdsFdwOptionSet *option
 		
 		else if (strcmp(def->defname, "use_remote_estimate") == 0)
 		{
-			if (option_set->use_remote_estimate)
+			if (option_set->use_remote_estimate != -1)
 				ereport(ERROR,
 					(errcode(ERRCODE_SYNTAX_ERROR),
 						errmsg("Redundant option: use_remote_estimate (%s)", defGetString(def))
@@ -776,7 +789,7 @@ void tdsSetDefaultOptions(TdsFdwOptionSet *option_set)
 		#endif
 	}
 	
-	if (!option_set->use_remote_estimate)
+	if (option_set->use_remote_estimate == -1)
 	{
 		option_set->use_remote_estimate = DEFAULT_USE_REMOTE_ESTIMATE;
 		
@@ -872,6 +885,14 @@ void tdsValidateForeignTableOptionSet(TdsFdwOptionSet *option_set)
 			));
 	}
 
+    /* Check option ranges */
+    if (option_set->use_remote_estimate < 0 || option_set->use_remote_estimate > 1)
+    {
+		ereport(ERROR,
+			(errcode(ERRCODE_SYNTAX_ERROR),
+				errmsg("Invalid value for use_remote_estimate: %d", option_set->use_remote_estimate)
+			));
+    }
 	#ifdef DEBUG
 		ereport(NOTICE,
 			(errmsg("----> finishing tdsValidateForeignTableOptionSet")
@@ -922,6 +943,7 @@ void tdsOptionSetInit(TdsFdwOptionSet* option_set)
 	option_set->port = 0;
 	option_set->database = NULL;
 	option_set->dbuse = 0;
+	option_set->sqlserver_ansi_mode = false;
 	option_set->tds_version = NULL;
 	option_set->msg_handler = NULL;
 	option_set->username = NULL;
@@ -931,7 +953,7 @@ void tdsOptionSetInit(TdsFdwOptionSet* option_set)
 	option_set->table_name = NULL;
 	option_set->row_estimate_method = NULL;
 	option_set->match_column_names = DEFAULT_MATCH_COLUMN_NAMES;
-	option_set->use_remote_estimate = 0;
+	option_set->use_remote_estimate = -1;
 	option_set->fdw_startup_cost = 0;
 	option_set->fdw_tuple_cost = 0;
 	option_set->local_tuple_estimate = 0;
